==> assert-is-named-typed-tuple-like-0.0.5.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# isNamedTypedTupleLike

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] [![dependencies][dependencies-image]][dependencies-url]

> Test if a value is [named typed tuple][@stdlib/utils/named-typed-tuple]-like.

<section class="installation">

## Installation

```bash
npm install @stdlib/assert-is-named-typed-tuple-like
```

</section>

<section class="usage">

## Usage

```javascript
var isNamedTypedTupleLike = require( '@stdlib/assert-is-named-typed-tuple-like' );
```

#### isNamedTypedTupleLike( value )

Tests if a value is [named typed tuple][@stdlib/utils/named-typed-tuple]-like.

```javascript
var namedtypedtuple = require( '@stdlib/utils-named-typed-tuple' );

var Point = namedtypedtuple( [ 'x', 'y' ] );
var p = new Point();

var bool = isNamedTypedTupleLike( p );
// returns true
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var namedtypedtuple = require( '@stdlib/utils-named-typed-tuple' );
var isNamedTypedTupleLike = require( '@stdlib/assert-is-named-typed-tuple-like' );

var Point = namedtypedtuple( [ 'x', 'y' ] );
var p = new Point();

var bool = isNamedTypedTupleLike( p );
// returns true

bool = isNamedTypedTupleLike( [ 1, 2, 3, 4 ] );
// returns false

bool = isNamedTypedTupleLike( {} );
// returns false

bool = isNamedTypedTupleLike( null );
// returns false
```

</section>

<!-- /.examples -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2021. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/assert-is-named-typed-tuple-like.svg
[npm-url]: https://npmjs.org/package/@stdlib/assert-is-named-typed-tuple-like

[test-image]: https://github.com/stdlib-js/assert-is-named-typed-tuple-like/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/assert-is-named-typed-tuple-like/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/assert-is-named-typed-tuple-like/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/assert-is-named-typed-tuple-like?branch=main

[dependencies-image]: https://img.shields.io/david/stdlib-js/assert-is-named-typed-tuple-like.svg
[dependencies-url]: https://david-dm.org/stdlib-js/assert-is-named-typed-tuple-like/main

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://gitter.im/stdlib-js/stdlib/

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/assert-is-named-typed-tuple-like/main/LICENSE

[@stdlib/utils/named-typed-tuple]: https://www.npmjs.com/package/@stdlib/utils-named-typed-tuple

</section>

<!-- /.links -->

==> assert-is-named-typed-tuple-like-0.0.6.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# isNamedTypedTupleLike

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] <!-- [![dependencies][dependencies-image]][dependencies-url] -->

> Test if a value is [named typed tuple][@stdlib/utils/named-typed-tuple]-like.

<section class="installation">

## Installation

```bash
npm install @stdlib/assert-is-named-typed-tuple-like
```

</section>

<section class="usage">

## Usage

```javascript
var isNamedTypedTupleLike = require( '@stdlib/assert-is-named-typed-tuple-like' );
```

#### isNamedTypedTupleLike( value )

Tests if a value is [named typed tuple][@stdlib/utils/named-typed-tuple]-like.

```javascript
var namedtypedtuple = require( '@stdlib/utils-named-typed-tuple' );

var Point = namedtypedtuple( [ 'x', 'y' ] );
var p = new Point();

var bool = isNamedTypedTupleLike( p );
// returns true
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var namedtypedtuple = require( '@stdlib/utils-named-typed-tuple' );
var isNamedTypedTupleLike = require( '@stdlib/assert-is-named-typed-tuple-like' );

var Point = namedtypedtuple( [ 'x', 'y' ] );
var p = new Point();

var bool = isNamedTypedTupleLike( p );
// returns true

bool = isNamedTypedTupleLike( [ 1, 2, 3, 4 ] );
// returns false

bool = isNamedTypedTupleLike( {} );
// returns false

bool = isNamedTypedTupleLike( null );
// returns false
```

</section>

<!-- /.examples -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

* * *

## See Also

-   <span class="package-name">[`@stdlib/utils/named-typed-tuple`][@stdlib/utils/named-typed-tuple]</span><span class="delimiter">: </span><span class="description">named typed tuple.</span>

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2022. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/assert-is-named-typed-tuple-like.svg
[npm-url]: https://npmjs.org/package/@stdlib/assert-is-named-typed-tuple-like

[test-image]: https://github.com/stdlib-js/assert-is-named-typed-tuple-like/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/assert-is-named-typed-tuple-like/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/assert-is-named-typed-tuple-like/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/assert-is-named-typed-tuple-like?branch=main

<!--

[dependencies-image]: https://img.shields.io/david/stdlib-js/assert-is-named-typed-tuple-like.svg
[dependencies-url]: https://david-dm.org/stdlib-js/assert-is-named-typed-tuple-like/main

-->

[umd]: https://github.com/umdjs/umd
[es-module]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Modules

[deno-url]: https://github.com/stdlib-js/assert-is-named-typed-tuple-like/tree/deno
[umd-url]: https://github.com/stdlib-js/assert-is-named-typed-tuple-like/tree/umd
[esm-url]: https://github.com/stdlib-js/assert-is-named-typed-tuple-like/tree/esm

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://gitter.im/stdlib-js/stdlib/

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/assert-is-named-typed-tuple-like/main/LICENSE

<!-- <related-links> -->

[@stdlib/utils/named-typed-tuple]: https://www.npmjs.com/package/@stdlib/utils-named-typed-tuple

<!-- </related-links> -->

</section>

<!-- /.links -->
